@@ -121,7 +121,7 @@ void log_event(int priority, char *format, ...)
 #else
 	openlog("sSMTP", LOG_PID, LOG_MAIL);
 #endif
-	syslog(priority, buf);
+	syslog(priority, "%s", buf);
 	closelog();
 #endif
 }
@@ -196,7 +196,7 @@ void die(char *format, ...)
 	va_end(ap);
 
 	(void)fprintf(stderr, "%s: %s\n", prog, buf);
-	log_event(LOG_ERR, buf);
+	log_event(LOG_ERR, "%s", buf);
 
 	/* Send message to dead.letter */
 	(void)dead_letter();
